@@ -1,10 +1,17 @@
 from datetime import datetime, timedelta
+from enum import Enum
 from typing import Optional
 
 from pydantic import BaseModel
 from pydantic.json import timedelta_isoformat
 
 
+class StepType(Enum):
+    PIPELINE = "pipeline"
+    FILTER = "filter"
+    FUNCTION = "function"
+
+
 class ManifestEntry(BaseModel):
     name: str
     start: datetime
@@ -12,23 +19,26 @@ class ManifestEntry(BaseModel):
     duration: Optional[timedelta]
 
     class Config:
+        use_enum_values = True
         json_encoders = {
             datetime: lambda dt: dt.timestamp(),
             timedelta: timedelta_isoformat,
         }
 
 
-class FilterManifestEntry(ManifestEntry):
-    pre_process: Optional[ManifestEntry]
-    post_process: Optional[ManifestEntry]
-
-
 class ManifestEntryList(list):
     ...
 
 
+class StepManifestEntry(ManifestEntry):
+    step_type: StepType
+    steps: Optional[ManifestEntryList]
+    pre_process: Optional[ManifestEntry]
+    post_process: Optional[ManifestEntry]
+
+
 class Manifest(ManifestEntry):
     """
     A running log of pipeline activity
     """
-    filters: ManifestEntryList = ManifestEntryList()
+    steps: ManifestEntryList = ManifestEntryList()
